@@ -23,8 +23,16 @@ for sect in ("FICS", "ICC"):
 path = addUserConfigPrefix("config")
 encoding = locale.getpreferredencoding()
 if os.path.isfile(path):
-    configParser.readfp(open(path, encoding=encoding))
-atexit.register(lambda: configParser.write(open(path, "w", encoding=encoding)))
+    with open(path, encoding=encoding) as fh:
+        configParser.read_file(fh)
+
+
+def save_config(path=path, encoding=encoding):
+    with open(path, "w", encoding=encoding) as fh:
+        configParser.write(fh)
+
+
+atexit.register(save_config)
 
 if sys.platform == "win32":
     username = os.environ["USERNAME"]
@@ -94,6 +102,7 @@ DEFAULTS = {
         "fullAnimation": True,
         "showCords": True,
         "drawGrid": True,
+        "activateSupportAlgorithm": False,
         "board_frame": 1,
         "board_style": 1,
         "pieceTheme": "Chessicons",
@@ -108,7 +117,6 @@ DEFAULTS = {
         "saveRatingChange": False,
         "indentPgn": False,
         "saveOwnGames": True,
-        "show_tip_at_startup": False,
         "dont_show_externals_at_startup": False,
         "max_analysis_spin": 3,
         "variation_threshold_spin": 50,
@@ -119,7 +127,8 @@ DEFAULTS = {
         "infinite_analysis": False,
         "opening_check": False,
         "opening_file_entry": default_book_path,
-        "book_depth_max": 8,
+        "book_depth_max": 13,
+        "book_exact_match": True,
         "endgame_check": False,
         "egtb_path": os.path.join(getDataPrefix()),
         "online_egtb_check": True,
@@ -158,7 +167,9 @@ DEFAULTS = {
         "learncombo3": 0,
         "welcome_image": addDataPrefix("glade/background.jpg"),
         "alarm_spin": 15,
-        "show_tip_at_startup": False,
+        "show_tip_at_startup": True,
+        "tips_seed": 0,
+        "tips_index": 0,
         "dont_show_externals_at_startup": False,
         "download_timestamp": False,
         "download_chess_db": False,
@@ -260,7 +271,8 @@ def set(key, value, section=section):
     # print("---conf set()", section, key, value)
     try:
         configParser.set(section, key, str(value))
-        configParser.write(open(path, "w"))
+        with open(path, "w") as fh:
+            configParser.write(fh)
     except Exception as err:
         log.error(
             "Unable to save configuration '%s'='%s' because of error: %s %s" %
