@@ -462,6 +462,7 @@ class Sidepanel:
         textedit.set_editable(True)
         textedit.set_cursor_visible(True)
         textedit.set_wrap_mode(Gtk.WrapMode.WORD)
+        textedit.set_accepts_tab(False)
 
         textbuffer = textedit.get_buffer()
         textbuffer.set_text(board.children[index])
@@ -476,21 +477,17 @@ class Sidepanel:
 
         response = dialog.run()
         dialog.destroy()
+        if response == Gtk.ResponseType.DELETE_EVENT:  # Escape key implies Cancel
+            response = Gtk.ResponseType.CANCEL
 
         (iter_first, iter_last) = textbuffer.get_bounds()
-        comment = textbuffer.get_text(iter_first, iter_last, False)
-        update = response in [Gtk.ResponseType.REJECT, Gtk.ResponseType.ACCEPT]
-        drop = (response == Gtk.ResponseType.REJECT) or (creation and not update) or (update and len(comment) == 0)
-        if drop:
-            if not creation:
-                self.gamemodel.needsSave = True
-            del board.children[index]
-        else:
-            if update:
-                if board.children[index] != comment:
-                    self.gamemodel.needsSave = True
+        comment = '' if response == Gtk.ResponseType.REJECT else textbuffer.get_text(iter_first, iter_last, False)
+        if response != Gtk.ResponseType.CANCEL and board.children[index] != comment:
+            if len(comment) == 0:
+                del board.children[index]
+            else:
                 board.children[index] = comment
-        if drop or update:
+            self.gamemodel.needsSave = True
             self.update()
 
     def menu_delete_comment(self, widget=None, board=None, index=0):
@@ -991,7 +988,7 @@ class Sidepanel:
 
         # Application of the filter on each element of the text
         if self.fan:
-            re_decoration = re.compile('^([^a-hprnkqx1-8]*|[0-9]+\.+)?([a-hprnkqx1-8=@]+)([^a-hprnkqx1-8]*)$', re.IGNORECASE)
+            re_decoration = re.compile(r'^([^a-hprnkqx1-8]*|[0-9]+\.+)?([a-hprnkqx1-8=@]+)([^a-hprnkqx1-8]*)$', re.IGNORECASE)
             re_move = re.compile('^([PRNBQK]?)(@?[a-h]?[1-8]?x?[a-h][1-8]=?)([RNBQK]?)(.*)$')
             return " ".join([process_word(word) for word in text.split(" ")])
         else:
@@ -1004,7 +1001,7 @@ class Sidepanel:
                        index=0,
                        level=0,
                        ini_board=None):
-        comment = re.sub("\[%.*?\]", "", comment)
+        comment = re.sub(r"\[%.*?\]", "", comment)
         if not comment:
             return
 
@@ -1046,7 +1043,7 @@ class Sidepanel:
 
         self.header_textbuffer.insert_with_tags_by_name(end_iter(), text, "head2")
         white_elo = self.gamemodel.tags['WhiteElo']
-        if white_elo:
+        if white_elo not in [None, '', '?', '0', 0]:
             self.header_textbuffer.insert_with_tags_by_name(end_iter(), " %s" % white_elo, "head1")
 
         self.header_textbuffer.insert_with_tags_by_name(end_iter(), " - ", "head1")
@@ -1055,7 +1052,7 @@ class Sidepanel:
         text = repr(self.gamemodel.players[1])
         self.header_textbuffer.insert_with_tags_by_name(end_iter(), text, "head2")
         black_elo = self.gamemodel.tags['BlackElo']
-        if black_elo:
+        if black_elo not in [None, '', '?', '0', 0]:
             self.header_textbuffer.insert_with_tags_by_name(end_iter(), " %s" % black_elo, "head1")
 
         result = reprResult[self.gamemodel.status]
@@ -1268,9 +1265,8 @@ class Sidepanel:
         """
         The method is called when a game is loaded.
         """
-        for ply in range(min(40, model.ply, len(model.boards))):
-            if ply >= model.lowply:
-                model.setOpening(ply)
+        if model.tags.get('ECO', '') == '' and model.tags.get('Opening', '') == '':
+            model.setOpening(redetermine=True)
         self.update()
 
     def on_game_changed(self, game, ply):
